@@ -360,25 +360,6 @@ def get_test_dir():
                                         'os_detect'))
 
 
-def test_fedora():
-    from rospkg.os_detect import Fedora, OsNotDetected
-    test_dir = os.path.join(get_test_dir(), 'fedora')
-    release_file, issue_file = [os.path.join(test_dir, x) for
-                                x in ["redhat-release", "issue"]]
-    detect = Fedora(release_file, issue_file)
-    assert detect.is_os()
-    assert detect.get_version() == '1'
-    assert detect.get_codename() == 'bordeaux', detect.get_codename()
-
-    detect = Fedora()
-    if not detect.is_os():
-        try:
-            detect.get_version()
-            assert False
-        except OsNotDetected:
-            pass
-
-
 def test_read_issue():
     from rospkg.os_detect import read_issue
     assert read_issue('/fake/file') is None
@@ -419,41 +400,6 @@ def test_tripwire_rhel():
     os_detect.get_detector('rhel')
 
 
-def test_redhat():
-    from rospkg.os_detect import Rhel, OsNotDetected
-    test_dir = os.path.join(get_test_dir(), 'rhel')
-
-    # go through several test files
-    detect = Rhel(os.path.join(test_dir, "redhat-release"))
-    assert detect.is_os()
-    assert detect.get_version() == '3'
-    assert detect.get_codename() == 'taroon'
-
-    detect = Rhel(os.path.join(test_dir, "redhat-release-tikanga"))
-    assert detect.is_os()
-    assert detect.get_version() == '5'
-    assert detect.get_codename() == 'tikanga'
-
-    detect = Rhel(os.path.join(test_dir, "redhat-release-nahant"))
-    assert detect.is_os()
-    assert detect.get_version() == '4'
-    assert detect.get_codename() == 'nahant'
-
-    # test freely
-    detect = Rhel()
-    if not detect.is_os():
-        try:
-            detect.get_version()
-            assert False
-        except OsNotDetected:
-            pass
-        try:
-            detect.get_codename()
-            assert False
-        except OsNotDetected:
-            pass
-
-
 def test_tripwire_slackware():
     from rospkg.os_detect import OsDetect
     os_detect = OsDetect()
@@ -556,6 +502,12 @@ def test_cygwin():
     test()
 
 
+def test_tripwire_centos():
+    from rospkg.os_detect import OsDetect
+    os_detect = OsDetect()
+    os_detect.get_detector('centos')
+
+
 def test_OsDetect():
     from rospkg.os_detect import OsDetect
     detect = OsDetect()
